@@ -4,7 +4,7 @@ use MooseX::Role::Parameterized;
 use Module::Runtime 'use_module';
 use List::AllUtils 'first_result';
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.1';
 
 =head1 Model::Envoy
 
@@ -377,6 +377,7 @@ use Moose::Role;
 Moose::Util::meta_attribute_alias('Envoy');
 
 use Moose::Util::TypeConstraints;
+use List::AllUtils 'any';
 
 has moose_class => (
     is  => 'ro',
@@ -412,7 +413,7 @@ sub _install_types {
         $self->_coerce_class($options->{isa});
     }
 
-    $options->{coerce} = 1;
+    $options->{coerce} = 1 unless $options->{moose_class} && any { $options->{moose_class} eq $_ } qw( HashRef ArrayRef );
 
     return $self->$orig($name,$options);
 }
